CountryDropdown class

Inheritance

Constructors

CountryDropdown({Key? key, CountryItemBuilder? selectedItemBuilder, CountryItemBuilder? listItemBuilder, bool printCountryName = false, bool showCountryFlag = true, PhoneCountryData? initialCountryData, bool triggerOnCountrySelectedInitially = true, List<PhoneCountryData>? filter, required ValueChanged<PhoneCountryData>? onCountrySelected, int elevation = 8, TextStyle? style, Widget? icon, Color? iconDisabledColor, Color? iconEnabledColor, double iconSize = 24.0, double? itemHeight = 60.0, Color? focusColor, FocusNode? focusNode, bool autofocus = false, Color? dropdownColor, InputDecoration? decoration, FormFieldValidator<PhoneCountryData>? validator, AutovalidateMode? autovalidateMode, double? menuMaxHeight, bool? enableFeedback, Widget? hint, EdgeInsetsGeometry? padding, Widget? disabledHint, BorderRadius? borderRadius, AlignmentGeometry alignment = AlignmentDirectional.centerStart})
filter if you need a predefined list of countries only, pass it here initialCountryData initial country data to be selected selectedItemBuilder use this if you want to make the selected item look the way you want listItemBuilder the same as selectedItemBuilder but to present items in an open list printCountryName if true, it will display a country name under its flat and country code while the menu is open triggerOnCountrySelectedInitially if you don't want onCountrySelected to be triggered right away if you set an initialPhoneCode param, pass false here. Description is here https://github.com/caseyryan/flutter_multi_formatter/issues/122
const

Properties

alignment → AlignmentGeometry
final
autofocus → bool
final
autovalidateMode → AutovalidateMode?
final
borderRadius → BorderRadius?
final
decoration → InputDecoration?
final
disabledHint → Widget?
final
final
elevation → int
final
enableFeedback → bool?
final
filter → List<PhoneCountryData>?
final
focusColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → Widget?
final
icon → Widget?
final
iconDisabledColor → Color?
final
iconEnabledColor → Color?
final
iconSize → double
final
initialCountryData → PhoneCountryData?
final
itemHeight → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listItemBuilder → CountryItemBuilder?
final
final
onCountrySelected → ValueChanged<PhoneCountryData>?
final
padding → EdgeInsetsGeometry?
final
printCountryName → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemBuilder → CountryItemBuilder?
final
showCountryFlag → bool
final
style → TextStyle?
final
triggerOnCountrySelectedInitially → bool
final
validator → FormFieldValidator<PhoneCountryData>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CountryDropdown>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited